aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorChris Robinson <[email protected]>2019-12-17 22:20:38 -0800
committerChris Robinson <[email protected]>2019-12-17 22:20:38 -0800
commit466c6faeb5deb4390cc9dda24fddd67152b07b90 (patch)
treed5840196fd84a45cf00a24ec082f434da83daad9
parent0a65ed21900ec7f6f0a820b674adb2746c3cbfcb (diff)
Correctly scale spatialized B-Format sources
-rw-r--r--alc/alu.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/alc/alu.cpp b/alc/alu.cpp
index c421ff12..d366e5f3 100644
--- a/alc/alu.cpp
+++ b/alc/alu.cpp
@@ -843,8 +843,8 @@ void CalcPanningAndFilters(ALvoice *voice, const ALfloat xpos, const ALfloat ypo
CalcAngleCoeffs(ScaleAzimuthFront(az, 1.5f), ev, Spread, coeffs);
}
- /* NOTE: W needs to be scaled due to FuMa normalization. */
- const float scale0{AmbiScale::FromFuMa[0]};
+ /* NOTE: W needs to be scaled according to channel scaling. */
+ const float scale0{GetAmbiScales(voice->mAmbiScaling)[0]};
ComputePanGains(&Device->Dry, coeffs, DryGain*scale0,
voice->mChans[0].mDryParams.Gains.Target);
for(ALuint i{0};i < NumSends;i++)